@@ -26,6 +26,7 @@ class PluginLoader(object):
         if self.plugins_dir[-1:] != '/':
             self.plugins_dir += '/'
         self.plugins = collections.deque()
+        self.modules = collections.deque()
 
     def load_all(self):
         logging.debug('Starting plugin loading')
@@ -46,7 +47,6 @@ class PluginLoader(object):
                 logging.debug('skipping %s due to invalid path (No __init__.py or not .py)' % full_path)
                 continue
             mod_dict = mod_dict.__dict__
-            self.plugins = []
             for key, value in mod_dict.items():
                 try:
                     is_subclass = issubclass(value, self.parent_class)
@@ -59,20 +59,10 @@ class PluginLoader(object):
                         enabled = True
 
                     if enabled:
-                        try:
-                            is_driver = value.driver
-                        except AttributeError:
-                            is_driver = False
-
-                        if is_driver:
-                            if found_driver:
-                                logging.error("More than one driver detected. Exiting.")
-                                sys.exit(1)
-                            found_driver = True
-                                
                         logging.debug('Initializing %s' % value.__name__)
                         instance = value()
                         instance.activate()
+                        self.modules.append(module)
                         self.plugins.append(instance)
                     else:
                         logging.debug('Skipping %s, not enabled' % value.__name__)
